default_ignore: [str] = ['.idea', '__pycache__', '.next', 'node_modules', 'assets', 'coverage', '.vscode',
                         'public', 'yarn.lock', 'jest.config.ts', '.env.local', 'package.json', 'README.md']


class Writer:
    @staticmethod
    def create_ignore_file(path: str = '.\\'):
        with open(f'{path}\\.counterignore', 'w') as ignore_file:
            for ignore in default_ignore:
                ignore_file.write(f'{ignore}\n')



import os

default_ignore: [str] = ['.idea', '__pycache__', '.next', 'node_modules', 'assets', 'coverage', '.vscode',
                         'public', 'yarn.lock', 'jest.config.ts', '.env.local', 'package.json', 'README.md']


class Reader:
    def __init__(self, ignore_blank_lines: bool = True, encoding: str = 'UTF-8'):
        self.__ignore_blank_lines: bool = ignore_blank_lines
        self.__encoding: str = encoding
        self.__ignore: [str] = default_ignore

    def __count_document_lines(self, document_path: str) -> int:
        """
        Open a document and count its lines.

        :param document_path: The document path.
        :return: The number of lines of the document.
        """

        try:
            with open(document_path, encoding=self.__encoding) as document:
                document_lines: [str] = document.readlines()
                lines_length: int = len(document_lines)

                for line in document_lines:
                    if self.__ignore_blank_lines and line is '\n':
                        lines_length -= 1
            return lines_length

        except PermissionError:
            return 0
        except UnicodeDecodeError:
            return 0

    @staticmethod
    def __get_ignore_config(ignore_file: str) -> [str]:
        ignore = ['.counterignore']
        with open(ignore_file) as document:
            document_lines: [str] = document.readlines()
            for line in document_lines:
                ignore.append(line.split('\n')[0])
        return ignore

    def open_input_path(self, input_path: str, total_lines: int = 0) -> int:
        if input_path is '.':
            input_path = '\\'

        isdir: bool = os.path.isdir(input_path)
        isfile: bool = os.path.isfile(input_path)

        if isdir:
            documents = os.listdir(input_path)
            if '.counterignore' in documents:
                ignore_file: str = input_path + '\\.counterignore'
                self.__ignore = self.__get_ignore_config(ignore_file)
            for document in documents:
                document_path = os.path.join(input_path, document)
                if os.path.isdir(document_path):
                    if os.path.split(document_path)[-1] in self.__ignore:
                        continue
                    total_lines += self.open_input_path(document_path)
                elif os.path.isfile(document_path):
                    if os.path.split(document_path)[-1] in self.__ignore:
                        continue
                    elif os.path.splitext(document_path)[-1] in self.__ignore:
                        continue
                    total_lines += self.__count_document_lines(document_path)

        elif isfile:
            total_lines += self.__count_document_lines(input_path)

        return total_lines



#!/usr/bin/env python3

from setuptools import setup, find_packages

if __name__ == '__main__':
    with open('README.md', 'r') as readme:
        long_description = readme.read()

    setup(
        name='felips-counter',
        version='0.0.1',
        author='Blackoutseeker (Felipe Pereira)',
        author_email='felipsdev@gmail.com',
        url='https://github.com/Blackoutseeker/Felips-Counter-Python',
        packages=find_packages(exclude='tests'),
        python_requires='>=3.7',
        description='Count your project lines easily!',
        long_description=long_description,
        long_description_content_type='text/markdown',
        keywords=['felips', 'counter'],
        entry_points={
            'console_scripts': [
                'counter=felips_counter.__main__:main'
            ]
        }
    )



#!/usr/bin/env python3

from felips_counter.src.reader import Reader
from felips_counter.src.writer import Writer
from argparse import ArgumentParser

writer: Writer = Writer()


def main():
    parser = ArgumentParser()
    parser.add_argument('-p', '--path', type=str, default='.\\', dest='path', help='the path')
    parser.add_argument('-i', '--init', dest='init', action='store_true', help='create a .counterignore file')
    parser.add_argument('-b', '--blank', dest='blank_lines', action='store_false', help='count blank lines')
    parser.add_argument('-v', '--version', dest='version', action='store_true', help='check version')
    args = parser.parse_args()

    path = args.path

    if args.version:
        print('0.0.1')
        exit()

    if args.init:
        writer.create_ignore_file(path)
        exit()

    blank_lines = args.blank_lines
    reader: Reader = Reader(blank_lines)
    total_lines = reader.open_input_path(path)
    print(f'Lines: {total_lines}')


if __name__ == '__main__':
    main()
